@@ -163,6 +163,26 @@ std::string mp_util::database_name_normalize(const std::string &s)
 
 }
 
+Z_RecordComposition *mp_util::piggyback_to_RecordComposition(
+    ODR odr, Odr_int result_set_size, Z_SearchRequest *sreq)
+{
+    Z_RecordComposition *comp = 0;
+    Odr_int present_dummy;
+    const char *element_set_name = 0;
+    mp::util::piggyback_sr(sreq, result_set_size,
+                           present_dummy, &element_set_name);
+    if (element_set_name)
+    {
+        comp  = (Z_RecordComposition *) odr_malloc(odr, sizeof(*comp));
+        comp->which = Z_RecordComp_simple;
+        comp->u.simple = (Z_ElementSetNames *)
+            odr_malloc(odr, sizeof(Z_ElementSetNames));
+        comp->u.simple->which = Z_ElementSetNames_generic;
+        comp->u.simple->u.generic = odr_strdup(odr, element_set_name);
+    }
+    return comp;
+}
+
 void mp_util::piggyback_sr(Z_SearchRequest *sreq,
                            Odr_int result_set_size,
                            Odr_int &number_to_present,
@@ -573,8 +593,9 @@ Z_APDU *mp::odr::create_scanResponse(const Z_APDU *in_apdu,
     return apdu;
 }
 
-Z_GDU *mp::odr::create_HTTP_Response(mp::Session &session,
-                                     Z_HTTP_Request *hreq, int code)
+Z_GDU *mp::odr::create_HTTP_Response_details(mp::Session &session,
+                                             Z_HTTP_Request *hreq, int code,
+                                             const char *details)
 {
     const char *response_version = "1.0";
     bool keepalive = false;
@@ -597,7 +618,7 @@ Z_GDU *mp::odr::create_HTTP_Response(mp::Session &session,
         response_version = "1.1";
     }
 
-    Z_GDU *gdu = z_get_HTTP_Response(m_odr, code);
+    Z_GDU *gdu = z_get_HTTP_Response_details(m_odr, code, details);
     Z_HTTP_Response *hres = gdu->u.HTTP_Response;
     hres->version = odr_strdup(m_odr, response_version);
     if (keepalive)
@@ -606,6 +627,13 @@ Z_GDU *mp::odr::create_HTTP_Response(mp::Session &session,
     return gdu;
 }
 
+Z_GDU *mp::odr::create_HTTP_Response(mp::Session &session,
+                                     Z_HTTP_Request *hreq, int code)
+{
+    return create_HTTP_Response_details(session, hreq, code, 0);
+
+}
+
 Z_ReferenceId **mp_util::get_referenceId(const Z_APDU *apdu)
 {
     switch (apdu->which)
